@@ -33,7 +33,7 @@ struct decryption_ctx {
 static struct kmem_cache *encryption_ctx_cache __read_mostly;
 static struct kmem_cache *decryption_ctx_cache __read_mostly;
 
-int packet_init_data_caches(void)
+int __init packet_init_data_caches(void)
 {
 	encryption_ctx_cache = kmem_cache_create("wireguard_encryption_ctx", sizeof(struct encryption_ctx), 0, 0, NULL);
 	if (!encryption_ctx_cache)
@@ -192,7 +192,7 @@ static inline bool skb_decrypt(struct sk_buff *skb, struct noise_symmetric_key *
 	if (!chacha20poly1305_decrypt_sg(sg, sg, skb->len, NULL, 0, PACKET_CB(skb)->nonce, key->key))
 		return false;
 
-	return pskb_trim(skb, skb->len - noise_encrypted_len(0)) == 0;
+	return !pskb_trim(skb, skb->len - noise_encrypted_len(0));
 }
 
 static inline bool get_encryption_nonce(u64 *nonce, struct noise_symmetric_key *key)
